Module: Google::Cloud::CloudDMS
- Defined in:
- lib/google/cloud/cloud_dms.rb,
lib/google/cloud/cloud_dms/version.rb
Constant Summary collapse
- VERSION =
"1.6.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.cloud_dms| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_dms library.
-
.data_migration_service(version: :v1, &block) ⇒ ::Object
Create a new client object for DataMigrationService.
-
.data_migration_service_available?(version: :v1) ⇒ boolean
Determines whether the DataMigrationService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.cloud_dms| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_dms library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
138 139 140 141 142 |
# File 'lib/google/cloud/cloud_dms.rb', line 138 def self.configure yield ::Google::Cloud.configure.cloud_dms if block_given? ::Google::Cloud.configure.cloud_dms end |
.data_migration_service(version: :v1, &block) ⇒ ::Object
Create a new client object for DataMigrationService.
By default, this returns an instance of
Google::Cloud::CloudDMS::V1::DataMigrationService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the DataMigrationService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the DataMigrationService service. You can determine whether the method will succeed by calling data_migration_service_available?.
About DataMigrationService
Database Migration service
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/cloud/cloud_dms.rb', line 72 def self.data_migration_service version: :v1, &block require "google/cloud/cloud_dms/#{version.to_s.downcase}" package_name = Google::Cloud::CloudDMS .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudDMS.const_get(package_name).const_get(:DataMigrationService) service_module.const_get(:Client).new(&block) end |
.data_migration_service_available?(version: :v1) ⇒ boolean
Determines whether the DataMigrationService service is supported by the current client. If true, you can retrieve a client object by calling data_migration_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataMigrationService service, or if the versioned client gem needs an update to support the DataMigrationService service.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/google/cloud/cloud_dms.rb', line 94 def self.data_migration_service_available? version: :v1 require "google/cloud/cloud_dms/#{version.to_s.downcase}" package_name = Google::Cloud::CloudDMS .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudDMS.const_get package_name return false unless service_module.const_defined? :DataMigrationService service_module = service_module.const_get :DataMigrationService service_module.const_defined? :Client rescue ::LoadError false end |